===========
pychromatic
===========

 a pretty color selector for python


* Free software: GNU General Public License v3
* Documentation: https://pychromatic.readthedocs.io.


Features
--------

* TODO
